EXPORTS
  _libwmf_get_fontdir
  fileIOCtxPtr
  gdCosT
  gdFontGiantData
  gdFontGiantRep
  gdFontLargeData
  gdFontLargeRep
  gdFontMediumBoldData
  gdFontMediumBoldRep
  gdFontSmallData
  gdFontSmallRep
  gdFontTinyData
  gdFontTinyRep
  gdSinT
  wmf_api_create
  wmf_api_destroy
  wmf_eps_function
  wmf_fig_function
  wmf_foreign_function
  wmf_gd_function
  wmf_gd_get_image_pixels
  wmf_gd_image_pixels
  wmf_help
  wmf_image_free
  wmf_image_load_jpg
  wmf_image_load_png
  wmf_image_save_eps
  wmf_ipa_bmp_b64
  wmf_ipa_bmp_color
  wmf_ipa_bmp_copy
  wmf_ipa_bmp_eps
  wmf_ipa_bmp_free
  wmf_ipa_bmp_interpolate
  wmf_ipa_bmp_jpg
  wmf_ipa_bmp_png
  wmf_ipa_bmp_read
  wmf_ipa_bmp_setcolor
  wmf_ipa_draw_text
  wmf_ipa_font_dir
  wmf_ipa_font_init
  wmf_ipa_font_lookup
  wmf_ipa_font_map
  wmf_ipa_font_map_gs
  wmf_ipa_font_map_set
  wmf_ipa_font_map_xml
  wmf_ipa_font_stringwidth
  wmf_ipa_page_format
  wmf_ipa_page_height
  wmf_ipa_page_width
  wmf_plot_function
  wmf_stream_create
  wmf_stream_destroy
  wmf_stream_printf
  wmf_stream_reset
  wmf_stream_rezet
  wmf_stream_sputs
  wmf_stream_zputs
  wmf_svg_function
  wmf_wmfxml_import
  wmf_x_function
  wmf_ztream_create
  wmf_ztream_destroy