EXPORTS
  wmf_aldus_checksum
  wmf_aliceblue
  wmf_antiquewhite
  wmf_aqua
  wmf_aquamarine
  wmf_assert
  wmf_attr_add
  wmf_attr_clear
  wmf_attr_free
  wmf_attr_new
  wmf_attr_query
  wmf_azure
  wmf_bbuf_input
  wmf_beige
  wmf_bisque
  wmf_black
  wmf_blanchedalmond
  wmf_blue
  wmf_blueviolet
  wmf_brown
  wmf_burlywood
  wmf_cadetblue
  wmf_calloc
  wmf_canvas
  wmf_canvas_arc
  wmf_canvas_bitmap
  wmf_canvas_done
  wmf_canvas_ellipse
  wmf_canvas_line
  wmf_canvas_polygon
  wmf_canvas_polygons
  wmf_canvas_polyline
  wmf_canvas_rect
  wmf_canvas_roundrect
  wmf_canvas_set_background
  wmf_canvas_set_bgcolor
  wmf_canvas_set_brush
  wmf_canvas_set_font
  wmf_canvas_set_pen
  wmf_canvas_set_polyfill
  wmf_canvas_set_textcolor
  wmf_canvas_text
  wmf_chartreuse
  wmf_chocolate
  wmf_coral
  wmf_cornflowerblue
  wmf_cornsilk
  wmf_crimson
  wmf_cyan
  wmf_darkblue
  wmf_darkcyan
  wmf_darkgoldenrod
  wmf_darkgray
  wmf_darkgreen
  wmf_darkgrey
  wmf_darkkhaki
  wmf_darkmagenta
  wmf_darkolivegreen
  wmf_darkorange
  wmf_darkorchid
  wmf_darkred
  wmf_darksalmon
  wmf_darkseagreen
  wmf_darkslateblue
  wmf_darkslategray
  wmf_darkslategrey
  wmf_darkturquoise
  wmf_darkviolet
  wmf_debug
  wmf_deeppink
  wmf_deepskyblue
  wmf_detach
  wmf_dimgray
  wmf_dimgrey
  wmf_display_size
  wmf_dodgerblue
  wmf_error
  wmf_file_close
  wmf_file_open
  wmf_file_read
  wmf_file_seek
  wmf_file_tell
  wmf_firebrick
  wmf_floralwhite
  wmf_forestgreen
  wmf_free
  wmf_fuchsia
  wmf_gainsboro
  wmf_ghostwhite
  wmf_gold
  wmf_goldenrod
  wmf_gray
  wmf_green
  wmf_greenyellow
  wmf_grey
  wmf_header_read
  wmf_honeydew
  wmf_hotpink
  wmf_indianred
  wmf_indigo
  wmf_ipa_color
  wmf_ipa_color_add
  wmf_ipa_color_count
  wmf_ipa_color_index
  wmf_ipa_color_init
  wmf_ivory
  wmf_khaki
  wmf_lavender
  wmf_lavenderblush
  wmf_lawngreen
  wmf_lemonchiffon
  wmf_lightblue
  wmf_lightcoral
  wmf_lightcyan
  wmf_lightgoldenrodyellow
  wmf_lightgray
  wmf_lightgreen
  wmf_lightgrey
  wmf_lightpink
  wmf_lightsalmon
  wmf_lightseagreen
  wmf_lightskyblue
  wmf_lightslategray
  wmf_lightslategrey
  wmf_lightsteelblue
  wmf_lightyellow
  wmf_lime
  wmf_limegreen
  wmf_linen
  wmf_lite_create
  wmf_lite_destroy
  wmf_magenta
  wmf_malloc
  wmf_maroon
  wmf_mediumaquamarine
  wmf_mediumblue
  wmf_mediumorchid
  wmf_mediumpurple
  wmf_mediumseagreen
  wmf_mediumslateblue
  wmf_mediumspringgreen
  wmf_mediumturquoise
  wmf_mediumvioletred
  wmf_mem_close
  wmf_mem_open
  wmf_mem_read
  wmf_mem_seek
  wmf_mem_tell
  wmf_midnightblue
  wmf_mintcream
  wmf_mistyrose
  wmf_moccasin
  wmf_navajowhite
  wmf_navy
  wmf_oldlace
  wmf_olive
  wmf_olivedrab
  wmf_orange
  wmf_orangered
  wmf_orchid
  wmf_palegoldenrod
  wmf_palegreen
  wmf_paleturquoise
  wmf_palevioletred
  wmf_papayawhip
  wmf_peachpuff
  wmf_peru
  wmf_pink
  wmf_play
  wmf_player_init
  wmf_plum
  wmf_powderblue
  wmf_printf
  wmf_purple
  wmf_read_16
  wmf_read_32
  wmf_realloc
  wmf_red
  wmf_rgb_black
  wmf_rgb_color
  wmf_rgb_white
  wmf_rosybrown
  wmf_royalblue
  wmf_saddlebrown
  wmf_salmon
  wmf_sandybrown
  wmf_scan
  wmf_seagreen
  wmf_seashell
  wmf_set_viewport_origin
  wmf_sienna
  wmf_silver
  wmf_size
  wmf_skyblue
  wmf_slateblue
  wmf_slategray
  wmf_slategrey
  wmf_snow
  wmf_springgreen
  wmf_status_function
  wmf_steelblue
  wmf_str_append
  wmf_strbuf_grow
  wmf_strdup
  wmf_strstr
  wmf_tan
  wmf_teal
  wmf_thistle
  wmf_tomato
  wmf_turquoise
  wmf_violet
  wmf_wheat
  wmf_white
  wmf_whitesmoke
  wmf_write
  wmf_write_begin
  wmf_write_end
  wmf_yellow
  wmf_yellowgreen